@@ -1,6 +1,6 @@
 package AnyEvent::ProcessPool;
 # ABSTRACT: Asynchronously runs code concurrently in a pool of perl processes
-$AnyEvent::ProcessPool::VERSION = '0.05';
+$AnyEvent::ProcessPool::VERSION = '0.06';
 use strict;
 use warnings;
 use Carp;
@@ -116,7 +116,7 @@ AnyEvent::ProcessPool - Asynchronously runs code concurrently in a pool of perl
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -170,6 +170,11 @@ arguments are passed unchanged to the code ref in the worker process. Returns a
 L<condvar|AnyEvent/CONDITION VARIABLES> that will block and return the task
 result when C<recv> is called on it.
 
+Alternately, the name of a task class may be supplied. The class must implement
+the methods 'new' (as a constructor) and 'run'. When using a task class, the
+arguments will be passed to the constructor (new) and the result of 'run' will
+be returned.
+
   # With an anonymous subroutine
   my $cv = $pool->async(sub{ ... });
 
@@ -179,6 +184,9 @@ result when C<recv> is called on it.
   # With optional parameter list
   my $cv = $pool->async(sub{ ... }, $arg1, $arg2, ...);
 
+  # With a task class
+  my $cv = $pool->async('My::Task', $arg1, ...);
+
 =head2 join
 
 Blocks until all pending tasks have completed. This does not prevent new tasks
